==> babel-plugin-string-to-lingui-0.1.5.tgz: package/src/index.js <==
const isStringOkey = (string, isJSX) => {
  const regex = /((^[A-Z]{1}.*?)|(\w*?\s\w*?.*?))/;
  const regexForMinMax = /(min-width)|(max-width)/;
  const regexForTwoUpperCaseInARow = /^[A-Z][a-z]*?[A-Z]/;
  const regexForPlural = /plural/;
  const regexForRem = /([0-9]rem)|([0-9]em)|([0-9]px)/;
  const regexForWrapper = /{*}/;
  const regexCSSRule = /:.{1,};/;
  const regexForLetter = /[a-z]/;
  const regexForObject = /\[object/;
  const regexForHTML = /<[a-z]/;
  const regexDate = /DD|MM|YY|HH|mm:ss/;
  const blackListRegex = [
    regexForMinMax,
    regexForPlural,
    regexForWrapper,
    regexForRem,
    regexCSSRule,
    regexForObject,
    regexForHTML,
    /Bearer/,
    regexDate
  ];

  return (
    regex.test(string) &&
    regexForLetter.test(string) &&
    (isJSX ||
      !(regexForTwoUpperCaseInARow.test(string) && !/\s/.test(string))) &&
    (isJSX ||
      !blackListRegex.some(regex => {
        return regex.test(string);
      }))
  );
};

const blackListOfAttributesToBeTransformed = [
  "defaultMessage",
  "p",
  "m",
  "width",
  "height",
  "flex",
  "minHeight",
  "maxHeight",
  "border",
  "borderTop",
  "borderRight",
  "borderBottom",
  "borderLeft",
  "lg",
  "md",
  "all",
  "xs",
  "xl",
  "xxl",
  "breakpoint",
  "sm",
  "viewBox",
  "d",
  "rel",
  "srcSet",
  "className",
  "Trans",
  "backgroundPosition",
  "backgroundSize"
];

const whiteListOfCallExpressions = [
  "show",
  "validation",
  "getErrorMessage",
  "handleClientSideError"
];

const blackListOfFileNames = [/.test./, /.stories./];

const atrIsNotInBlackList = path => {
  const atrName =
    (path && path.parent && path.parent.name && path.parent.name.name) ||
    (path && path.parent && path.parent.key && path.parent.key.name);
  const parentAtrName =
    path &&
    path.parentPath &&
    path.parentPath.parent &&
    path.parentPath.parent.name &&
    path.parentPath.parent.name.name;

  const parentOfParentAtrName =
    path.parentPath &&
    path.parentPath.parentPath &&
    path.parentPath.parentPath.parent &&
    path.parentPath.parentPath.parent.name &&
    path.parentPath.parentPath.parent.name.name;

  const openingElementName =
    path.parent &&
    path.parent.openingElement &&
    path.parent.openingElement.name &&
    path.parent.openingElement.name.name;
  return (
    !blackListOfAttributesToBeTransformed.includes(atrName) &&
    !blackListOfAttributesToBeTransformed.includes(parentAtrName) &&
    !blackListOfAttributesToBeTransformed.includes(parentOfParentAtrName) &&
    !blackListOfAttributesToBeTransformed.includes(openingElementName)
  );
};

const isPropertyKey = (path, value) => {
  if (path.parentPath.isProperty()) {
    return path.parent.key.value === value;
  }
  return false;
};

const isInWhiteListCallExpression = path => {
  const name =
    (path.parentPath.node.callee && path.parentPath.node.callee.name) ||
    (path.parentPath.node.callee &&
      path.parentPath.node.callee.property &&
      path.parentPath.node.callee.property.name);

  return whiteListOfCallExpressions.includes(name);
};

const isCallExpression = path =>
  (path.parentPath.isCallExpression() || path.parentPath.isNewExpression()) &&
  !isInWhiteListCallExpression(path);

const isJSXAttribute = path =>
  path.parentPath.isJSXAttribute() ||
  path.parentPath.parentPath.isJSXAttribute();

const replaceWith = (t, path, replacement) => {
  const el = isJSXAttribute(path)
    ? t.jSXExpressionContainer(replacement)
    : replacement;

  if (path.parentPath.isJSXExpressionContainer()) {
    path.parentPath.replaceWith(el);
  } else {
    path.replaceWith(el);
  }
};

const StringMod = t =>
  function(path, state) {
    const value = path.node.value && path.node.value.trim();
    const isOkey = isStringOkey(value);
    if (
      Boolean(value) &&
      isOkey &&
      atrIsNotInBlackList(path) &&
      !isPropertyKey(path, value) &&
      !isCallExpression(path)
    ) {
      const replacement = t.callExpression(
        t.memberExpression(t.Identifier("i18n"), t.Identifier("_"), false),
        [t.stringLiteral(value)]
      );
      replaceWith(t, path, replacement);
    }
  };

const TemplateMod = t =>
  function(path, state) {
    const parent = path.parent;
    const quasisCookedArray = path.node.quasis.map(
      quasis => quasis.value.cooked
    );
    const quasisValue = quasisCookedArray.join("").trim();
    const isOkey = isStringOkey(quasisValue);

    if (
      !t.isTaggedTemplateExpression(parent) &&
      isOkey &&
      atrIsNotInBlackList(path) &&
      !isCallExpression(path)
    ) {
      const child =
        path.node.expressions.length === 0
          ? t.stringLiteral(quasisValue)
          : t.taggedTemplateExpression(t.Identifier("t"), path.node);

      const replacement = t.callExpression(
        t.memberExpression(t.Identifier("i18n"), t.Identifier("_"), false),
        [child]
      );
      path.replaceWith(replacement);
    }
  };

const getChildrenWithSpaces = (path, t) => {
  const children = [];
  path.parentPath.node.children.forEach(el => {
    if (t.isJSXText(el)) {
      children.push(el);
    } else {
      children.push(t.jsxText(" "));
      children.push(el);
      children.push(t.jsxText(" "));
    }
  });
  return children;
};

const JSXTextMod = (t, onlyComplex) =>
  function(path, state) {
    const value = path.node.value && path.node.value.trim();
    const childrenLength = path.parent.children.length;
    const parentHasTrans = path.findParent(p => {
      const openingElementName =
        p &&
        p.parent &&
        p.parent.openingElement &&
        p.parent.openingElement.name &&
        p.parent.openingElement.name.name;

      return openingElementName === "Trans";
    });

    const replaceOnleComplex = !onlyComplex || childrenLength > 1;
    const isOkey = isStringOkey(value, true);

    if (
      Boolean(value) &&
      isOkey &&
      atrIsNotInBlackList(path) &&
      !isPropertyKey(path, value) &&
      !isCallExpression(path) &&
      !parentHasTrans &&
      replaceOnleComplex
    ) {
      const replacedPath =
        childrenLength > 1 ? getChildrenWithSpaces(path, t) : [path.node];

      const replacement = t.jsxElement(
        t.jsxOpeningElement(t.jsxIdentifier("Trans"), []),
        t.jsxClosingElement(t.jsxIdentifier("Trans")),
        replacedPath
      );

      if (childrenLength > 1) {
        const newParent = path.parentPath;
        newParent.node.children = [replacement];
        path.parentPath.replaceWith(newParent);
      } else {
        path.replaceWith(replacement);
      }
    }
  };

function stringLiteralReplace(_ref) {
  const t = _ref.types;

  return {
    manipulateOptions(opts, parserOpts) {
      parserOpts.plugins.push("classProperties");
      parserOpts.plugins.push("optionalChaining");
      parserOpts.plugins.push("objectRestSpread");
      parserOpts.plugins.push("nullishCoalescingOperator");
      parserOpts.plugins.push("numericSeparator");
    },
    visitor: {
      Program(path, opts) {
        if (blackListOfFileNames.some(regex => regex.test(opts.filename))) {
          return null;
        }
        let isTrans = false;
        let isI18n = false;
        let isMacro = false;
        let isLinguiCore = false;
        let isLinguiMacro = false;
        let isMacroTImported = false;
        let isMacroTransImported = false;

        const getMacroImport = (_isMacro, _isTrans) => {
          if (_isMacro) {
            isMacroTImported = true;
          }
          if (_isTrans) {
            isMacroTransImported = true;
          }
          return t.ImportDeclaration(
            [
              _isMacro &&
                t.ImportSpecifier(t.Identifier("t"), t.Identifier("t")),
              _isTrans &&
                t.ImportSpecifier(t.Identifier("Trans"), t.Identifier("Trans"))
            ].filter(Boolean),
            t.stringLiteral("@lingui/macro")
          );
        };

        path.traverse({
          TemplateLiteral: TemplateMod(t),
          StringLiteral: StringMod(t),
          JSXText: JSXTextMod(t, true)
        });

        path.traverse({
          JSXText: JSXTextMod(t, false)
        });

        path.traverse({
          JSXIdentifier(jsxPath) {
            if (jsxPath && jsxPath.node) {
              const name = jsxPath.node.name;
              if (name === "Trans") {
                isTrans = true;
              }
            }
          },
          MemberExpression(expPath) {
            if (expPath && expPath.node && expPath.node.object) {
              const name = expPath.node.object.name;
              if (name === "i18n") {
                isI18n = true;
              }
            }
          },
          TaggedTemplateExpression(taggedPath) {
            if (taggedPath && taggedPath.node && taggedPath.node.tag) {
              const name = taggedPath.node.tag.name;
              if (name === "t") {
                isMacro = true;
              }
            }
          },
          ImportDeclaration(importPath) {
            if (importPath && importPath.node && importPath.node.source) {
              const name = importPath.node.source.value;
              const specifiers = importPath.node.specifiers.map(
                specifier => specifier.local.name
              );
              if (name === "app/i18n") {
                isLinguiCore = true;
              }
              if (name === "@lingui/macro") {
                isLinguiMacro = true;
                if (specifiers.includes("t")) {
                  isMacroTImported = true;
                }
                if (specifiers.includes("Trans")) {
                  isMacroTransImported = true;
                }
              }
            }
          }
        });

        path.traverse({
          ImportDeclaration(importPath) {
            if (importPath && importPath.node && importPath.node.source) {
              const name = importPath.node.source.value;
              if (name === "@lingui/macro") {
                if (
                  (isMacro && !isMacroTImported) ||
                  (isTrans && !isMacroTransImported)
                ) {
                  importPath.replaceWith(getMacroImport(isMacro, isTrans));
                }
              }
            }
          }
        });

        if (isI18n && !isLinguiCore) {
          path.unshiftContainer(
            "body",
            t.ImportDeclaration(
              [t.ImportSpecifier(t.Identifier("i18n"), t.Identifier("i18n"))],
              t.stringLiteral("app/i18n")
            )
          );
        }
        if (!isLinguiMacro && (isMacro || isTrans)) {
          path.unshiftContainer(
            "body",
            t.ImportDeclaration(
              [
                isMacro &&
                  !isMacroTImported &&
                  t.ImportSpecifier(t.Identifier("t"), t.Identifier("t")),
                isTrans &&
                  !isMacroTransImported &&
                  t.ImportSpecifier(
                    t.Identifier("Trans"),
                    t.Identifier("Trans")
                  )
              ].filter(Boolean),
              t.stringLiteral("@lingui/macro")
            )
          );
        }
        return null;
      }
    }
  };
}

module.exports = stringLiteralReplace;

==> babel-plugin-string-to-lingui-0.1.6.tgz: package/src/index.js <==
const isStringOkey = (string, isJSX) => {
  const regex = /((^[A-Z]{1}.*?)|(\w*?\s\w*?.*?))/;
  const regexForMinMax = /(min-width)|(max-width)/;
  const regexForTwoUpperCaseInARow = /^[A-Z][a-z]*?[A-Z]/;
  const regexForPlural = /plural/;
  const regexForRem = /([0-9]rem)|([0-9]em)|([0-9]px)/;
  const regexForWrapper = /{*}/;
  const regexCSSRule = /:.{1,};/;
  const regexForLetter = /[a-z]/;
  const regexForObject = /\[object/;
  const regexForHTML = /<[a-z]/;
  const regexDate = /DD|MM|YY|HH|mm:ss/;
  const blackListRegex = [
    regexForMinMax,
    regexForPlural,
    regexForWrapper,
    regexForRem,
    regexCSSRule,
    regexForObject,
    regexForHTML,
    /Bearer/,
    regexDate
  ];

  return (
    regex.test(string) &&
    regexForLetter.test(string) &&
    (isJSX ||
      !(regexForTwoUpperCaseInARow.test(string) && !/\s/.test(string))) &&
    (isJSX ||
      !blackListRegex.some(regex => {
        return regex.test(string);
      }))
  );
};

const blackListOfAttributesToBeTransformed = [
  "defaultMessage",
  "p",
  "m",
  "width",
  "height",
  "flex",
  "minHeight",
  "maxHeight",
  "border",
  "borderTop",
  "borderRight",
  "borderBottom",
  "borderLeft",
  "lg",
  "md",
  "all",
  "xs",
  "xl",
  "xxl",
  "breakpoint",
  "sm",
  "viewBox",
  "d",
  "rel",
  "srcSet",
  "className",
  "Trans",
  "backgroundPosition",
  "backgroundSize"
];

const whiteListOfCallExpressions = [
  "show",
  "validation",
  "getErrorMessage",
  "handleClientSideError"
];

const blackListOfFileNames = [/.test./, /.stories./];

const atrIsNotInBlackList = path => {
  const atrName =
    (path && path.parent && path.parent.name && path.parent.name.name) ||
    (path && path.parent && path.parent.key && path.parent.key.name);
  const parentAtrName =
    path &&
    path.parentPath &&
    path.parentPath.parent &&
    path.parentPath.parent.name &&
    path.parentPath.parent.name.name;

  const parentOfParentAtrName =
    path.parentPath &&
    path.parentPath.parentPath &&
    path.parentPath.parentPath.parent &&
    path.parentPath.parentPath.parent.name &&
    path.parentPath.parentPath.parent.name.name;

  const openingElementName =
    path.parent &&
    path.parent.openingElement &&
    path.parent.openingElement.name &&
    path.parent.openingElement.name.name;

  return (
    !blackListOfAttributesToBeTransformed.includes(atrName) &&
    !blackListOfAttributesToBeTransformed.includes(parentAtrName) &&
    !blackListOfAttributesToBeTransformed.includes(parentOfParentAtrName) &&
    !blackListOfAttributesToBeTransformed.includes(openingElementName)
  );
};

const isPropertyKey = (path, value) => {
  if (path.parentPath.isProperty()) {
    return path.parent.key.value === value;
  }
  return false;
};

const isInWhiteListCallExpression = path => {
  const name =
    (path.parentPath.node.callee && path.parentPath.node.callee.name) ||
    (path.parentPath.node.callee &&
      path.parentPath.node.callee.property &&
      path.parentPath.node.callee.property.name);

  return whiteListOfCallExpressions.includes(name);
};

const isForbiddenParentType = path =>
  ((path.parentPath.isCallExpression() || path.parentPath.isNewExpression()) &&
    !isInWhiteListCallExpression(path)) ||
  path.parentPath.isTSEnumMember();

const isJSXAttribute = path =>
  path.parentPath.isJSXAttribute() ||
  path.parentPath.parentPath.isJSXAttribute();

const replaceWith = (t, path, replacement) => {
  const el = isJSXAttribute(path)
    ? t.jSXExpressionContainer(replacement)
    : replacement;

  if (path.parentPath.isJSXExpressionContainer()) {
    path.parentPath.replaceWith(el);
  } else {
    path.replaceWith(el);
  }
};

const StringMod = t =>
  function(path, state) {
    const value = path.node.value && path.node.value.trim();
    const isOkey = isStringOkey(value);
    if (
      Boolean(value) &&
      isOkey &&
      atrIsNotInBlackList(path) &&
      !isPropertyKey(path, value) &&
      !isForbiddenParentType(path)
    ) {
      const replacement = t.callExpression(
        t.memberExpression(t.Identifier("i18n"), t.Identifier("_"), false),
        [t.stringLiteral(value)]
      );
      replaceWith(t, path, replacement);
    }
  };

const TemplateMod = t =>
  function(path, state) {
    const parent = path.parent;
    const quasisCookedArray = path.node.quasis.map(
      quasis => quasis.value.cooked
    );
    const quasisValue = quasisCookedArray.join("").trim();
    const isOkey = isStringOkey(quasisValue);

    if (
      !t.isTaggedTemplateExpression(parent) &&
      isOkey &&
      atrIsNotInBlackList(path) &&
      !isForbiddenParentType(path)
    ) {
      const child =
        path.node.expressions.length === 0
          ? t.stringLiteral(quasisValue)
          : t.taggedTemplateExpression(t.Identifier("t"), path.node);

      const replacement = t.callExpression(
        t.memberExpression(t.Identifier("i18n"), t.Identifier("_"), false),
        [child]
      );
      path.replaceWith(replacement);
    }
  };

const getChildrenWithSpaces = (path, t) => {
  const children = [];
  path.parentPath.node.children.forEach(el => {
    if (t.isJSXText(el)) {
      children.push(el);
    } else {
      children.push(t.jsxText(" "));
      children.push(el);
      children.push(t.jsxText(" "));
    }
  });
  return children;
};

const JSXTextMod = (t, onlyComplex) =>
  function(path, state) {
    const value = path.node.value && path.node.value.trim();
    const childrenLength = path.parent.children.length;
    const parentHasTrans = path.findParent(p => {
      const openingElementName =
        p &&
        p.parent &&
        p.parent.openingElement &&
        p.parent.openingElement.name &&
        p.parent.openingElement.name.name;

      return openingElementName === "Trans";
    });

    const replaceOnleComplex = !onlyComplex || childrenLength > 1;
    const isOkey = isStringOkey(value, true);

    if (
      Boolean(value) &&
      isOkey &&
      atrIsNotInBlackList(path) &&
      !isPropertyKey(path, value) &&
      !isForbiddenParentType(path) &&
      !parentHasTrans &&
      replaceOnleComplex
    ) {
      const replacedPath =
        childrenLength > 1 ? getChildrenWithSpaces(path, t) : [path.node];

      const replacement = t.jsxElement(
        t.jsxOpeningElement(t.jsxIdentifier("Trans"), []),
        t.jsxClosingElement(t.jsxIdentifier("Trans")),
        replacedPath
      );

      if (childrenLength > 1) {
        const newParent = path.parentPath;
        newParent.node.children = [replacement];
        path.parentPath.replaceWith(newParent);
      } else {
        path.replaceWith(replacement);
      }
    }
  };

function stringLiteralReplace(_ref) {
  const t = _ref.types;

  return {
    manipulateOptions(opts, parserOpts) {
      parserOpts.plugins.push("classProperties");
      parserOpts.plugins.push("optionalChaining");
      parserOpts.plugins.push("objectRestSpread");
      parserOpts.plugins.push("nullishCoalescingOperator");
      parserOpts.plugins.push("numericSeparator");
    },
    visitor: {
      Program(path, opts) {
        if (blackListOfFileNames.some(regex => regex.test(opts.filename))) {
          return null;
        }
        let isTrans = false;
        let isI18n = false;
        let isMacro = false;
        let isLinguiCore = false;
        let isLinguiMacro = false;
        let isMacroTImported = false;
        let isMacroTransImported = false;

        const getMacroImport = (_isMacro, _isTrans) => {
          if (_isMacro) {
            isMacroTImported = true;
          }
          if (_isTrans) {
            isMacroTransImported = true;
          }
          return t.ImportDeclaration(
            [
              _isMacro &&
                t.ImportSpecifier(t.Identifier("t"), t.Identifier("t")),
              _isTrans &&
                t.ImportSpecifier(t.Identifier("Trans"), t.Identifier("Trans"))
            ].filter(Boolean),
            t.stringLiteral("@lingui/macro")
          );
        };

        path.traverse({
          TemplateLiteral: TemplateMod(t),
          StringLiteral: StringMod(t),
          JSXText: JSXTextMod(t, true)
        });

        path.traverse({
          JSXText: JSXTextMod(t, false)
        });

        path.traverse({
          JSXIdentifier(jsxPath) {
            if (jsxPath && jsxPath.node) {
              const name = jsxPath.node.name;
              if (name === "Trans") {
                isTrans = true;
              }
            }
          },
          MemberExpression(expPath) {
            if (expPath && expPath.node && expPath.node.object) {
              const name = expPath.node.object.name;
              if (name === "i18n") {
                isI18n = true;
              }
            }
          },
          TaggedTemplateExpression(taggedPath) {
            if (taggedPath && taggedPath.node && taggedPath.node.tag) {
              const name = taggedPath.node.tag.name;
              if (name === "t") {
                isMacro = true;
              }
            }
          },
          ImportDeclaration(importPath) {
            if (importPath && importPath.node && importPath.node.source) {
              const name = importPath.node.source.value;
              const specifiers = importPath.node.specifiers.map(
                specifier => specifier.local.name
              );
              if (name === "app/i18n") {
                isLinguiCore = true;
              }
              if (name === "@lingui/macro") {
                isLinguiMacro = true;
                if (specifiers.includes("t")) {
                  isMacroTImported = true;
                }
                if (specifiers.includes("Trans")) {
                  isMacroTransImported = true;
                }
              }
            }
          }
        });

        path.traverse({
          ImportDeclaration(importPath) {
            if (importPath && importPath.node && importPath.node.source) {
              const name = importPath.node.source.value;
              if (name === "@lingui/macro") {
                if (
                  (isMacro && !isMacroTImported) ||
                  (isTrans && !isMacroTransImported)
                ) {
                  importPath.replaceWith(getMacroImport(isMacro, isTrans));
                }
              }
            }
          }
        });

        if (isI18n && !isLinguiCore) {
          path.unshiftContainer(
            "body",
            t.ImportDeclaration(
              [t.ImportSpecifier(t.Identifier("i18n"), t.Identifier("i18n"))],
              t.stringLiteral("app/i18n")
            )
          );
        }
        if (!isLinguiMacro && (isMacro || isTrans)) {
          path.unshiftContainer(
            "body",
            t.ImportDeclaration(
              [
                isMacro &&
                  !isMacroTImported &&
                  t.ImportSpecifier(t.Identifier("t"), t.Identifier("t")),
                isTrans &&
                  !isMacroTransImported &&
                  t.ImportSpecifier(
                    t.Identifier("Trans"),
                    t.Identifier("Trans")
                  )
              ].filter(Boolean),
              t.stringLiteral("@lingui/macro")
            )
          );
        }
        return null;
      }
    }
  };
}

module.exports = stringLiteralReplace;
